import { DeepClient, SerialOperation } from '@deep-foundation/deeplinks/imports/client';
import { Link } from '@deep-foundation/deeplinks/imports/minilinks';
import { PushNotification } from './push-notification';
/**
  * Gets serial operations to update {@link Package.PushNotification}
  *
  * @example
  * #### Update {@link Package.PushNotification}
 ```ts
 const {serialOperations, linkIds} = await getPushNotificationValueUpdateSerialOperations({
   deep,
   pushNotification: {
     title,
     body,
   }
 });
 await deep.serial({
   operations: serialOperations
 })
 ```
  */
export declare function getPushNotificationValueUpdateSerialOperations(param: GetPushNotificationValueUpdateSerialOperationsParam): Promise<Array<SerialOperation>>;
export type GetPushNotificationValueUpdateSerialOperationsParam = {
    /**
     * DeepClient
     */
    deep: DeepClient;
    /**
     * PushNotification
     */
    pushNotification: PushNotification;
} & ({
    /**
     * PushNotification Link Id
     */
    pushNotificationLinkId: number;
} | {
    /**
     * PushNotification Link
     */
    pushNotificationLink: Link<number>;
});
