import { DeepClient, SerialOperation } from '@deep-foundation/deeplinks/imports/client';
import { Link } from '@deep-foundation/deeplinks/imports/minilinks';
/**
  * Gets serial operations to update {@link Package.ServiceAccount}
  *
  * @example
  * #### Update {@link Package.ServiceAccount}
 ```ts
 const {serialOperations, linkIds} = await getServiceAccountValueUpdateSerialOperations({
   deep,
   serviceAccount: {
     title,
     body,
   }
 });
 await deep.serial({
   operations: serialOperations
 })
 ```
  */
export declare function getServiceAccountValueUpdateSerialOperations(param: GetServiceAccountValueUpdateSerialOperationsParam): Promise<Array<SerialOperation>>;
export type GetServiceAccountValueUpdateSerialOperationsParam = {
    /**
     * DeepClient
     */
    deep: DeepClient;
    /**
     * Service Account
     */
    serviceAccount: object;
} & ({
    /**
     * ServiceAccount Link Id
     */
    serviceAccountLinkId: number;
} | {
    /**
     * ServiceAccount Link
     */
    serviceAccountLink: Link<number>;
});
