import { createSerialOperation } from '@deep-foundation/deeplinks/imports/gql';
/**
  * Gets serial operations to update {@link Package.WebPushCertificate}
  *
  * @example
  * #### Update {@link Package.WebPushCertificate}
 ```ts
 const {serialOperations, linkIds} = await getWebPushCertificateValueUpdateSerialOperations({
   deep,
   webPushCertificate: {
     title,
     body,
   }
 });
 await deep.serial({
   operations: serialOperations
 })
 ```
  */
export async function getWebPushCertificateValueUpdateSerialOperations(param) {
    const { deep, webPushCertificate } = param;
    const webPushCertificateLink = await getWebPushCertificateLink();
    const serialOperations = await getSerialOperations({
        webPushCertificateLink,
        value: webPushCertificate,
    });
    return serialOperations;
    async function getWebPushCertificateLink() {
        let webPushCertificateLink;
        if ('webPushCertificateLinkId' in param) {
            if (!param.webPushCertificateLinkId) {
                throw new Error(`webPushCertificateLinkId is undefined`);
            }
            const { data } = await deep.select({
                id: param.webPushCertificateLinkId,
            });
            webPushCertificateLink = data[0];
        }
        else if ('webPushCertificateLink' in param) {
            if (!param.webPushCertificateLink) {
                throw new Error(`webPushCertificateLink is undefined`);
            }
            webPushCertificateLink = param.webPushCertificateLink;
        }
        else {
            throw new Error(`Either webPushCertificateLink or webPushCertificateLinkId must be passed`);
        }
        return webPushCertificateLink;
    }
    async function getValueInsertSerialOperation({ webPushCertificateLink, value, }) {
        return createSerialOperation({
            table: 'strings',
            type: 'insert',
            objects: {
                link_id: webPushCertificateLink.id,
                value: value,
            },
        });
    }
    async function getValueUpdateSerialOperation({ webPushCertificateLink, value, }) {
        return createSerialOperation({
            table: 'strings',
            type: 'update',
            exp: {
                link_id: webPushCertificateLink.id,
            },
            value: {
                value: value,
            },
        });
    }
    async function getSerialOperations({ webPushCertificateLink, value, }) {
        let serialOperations = [];
        if (!webPushCertificateLink.value) {
            serialOperations.push(await getValueUpdateSerialOperation({
                webPushCertificateLink,
                value,
            }));
        }
        else {
            serialOperations.push(await getValueInsertSerialOperation({
                webPushCertificateLink,
                value,
            }));
        }
        return serialOperations;
    }
}
